fisx: Member List

fisx

fisx::Math Member List

This is the complete list of members for fisx::Math, including all inherited members.

AS_5_1_53(const double &x) | fisx::Math | static
AS_5_1_56(const double &x) | fisx::Math | static
deBoerD(const double &x) | fisx::Math | static
deBoerL0(const double &mu1, const double &mu2, const double &muj, const double &density, const double &thickness) | fisx::Math | static
deBoerV(const double &p, const double &q, const double &d1, const double &d2, const double &mu_1_j, const double &mu_2_j, const double &mu_b_j_d_t) (defined in fisx::Math) | fisx::Math | static
deBoerW(const double &a, const double &b, const double &d) | fisx::Math | static
deBoerX(const double &p, const double &q, const double &d1, const double &d2, const double &mu_1_j, const double &mu_2_j, const double &mu_b_j_d_t=0.0) | fisx::Math | static
deBoerY(const double &a, const double &b, const double &c, const double &d) | fisx::Math | static
E1(const double &x) | fisx::Math | static
En(const int &n, const double &x) | fisx::Math | static
erf(const double &x) | fisx::Math | static
erfc(const double &x) | fisx::Math | static
getFWHM(const double &energy, const double &noise, const double &fano, const double &quantumEnergy=0.00385) | fisx::Math | static
isFiniteNumber(const double &x) | fisx::Math | static
isNumber(const double &x) | fisx::Math | static